==> spatPomp_0.30.2.0.tar.gz: spatPomp/man/macros/cite.Rd <==
% unlike in latex, new lines within \newcommand end the command (even using %)
\newcommand{\Anderson2001}{J.L. Anderson. An Ensemble Adjustment Kalman Filter for Data Assimilation. \emph{Monthly Weather Review} \bold{129}, 2884--2903, 2001.}

\newcommand{\arulampalam2002}{Arulampalam, M. S., Maskell, S., Gordon, N. and Clapp, T. (2002) A Tutorial on Particle Filters for Online Nonlinear/Non-Gaussian Bayesian Tracking. \emph{IEEE Trans. Sig. Proc.}, \bold{50(2)}, 174--188.}

\newcommand{\asfaw2020}{Asfaw, K., Park, J., Ho, A., King, A. A., and Ionides, E. L. (2020) Partially observed Markov processes with spatial structure via the R package spatPomp. \emph{ArXiv}: 2101.01157. \doi{10.48550/arXiv.2101.01157}}

\newcommand{\asfaw2021thesis}{Asfaw, K. T. (2021). Simulation-based Inference for Partially Observed Markov Process Models with Spatial Coupling. University of Michigan Doctoral dissertation. \doi{10.7302/2751}}

\newcommand{\breto2019}{Breto, C., Ionides, E. L. and King, A. A. (2019) Panel Data Analysis via Mechanistic Models. \emph{Journal of the American Statistical Association}. \doi{10.1080/01621459.2019.1604367}}

\newcommand{\dalziel2016}{Dalziel, Benjamin D. et al. (2016) Persistent chaos of measles epidemics in the prevaccination United States caused by a small change in seasonal transmission patterns. \emph{PLoS Computational Biology}, \bold{12(2)}, e1004655. \doi{10.5061/dryad.r4q34}}

\newcommand{\Evensen1994}{G. Evensen. Sequential data assimilation with a nonlinear quasi-geostrophic model using Monte Carlo methods to forecast error statistics. \emph{Journal of Geophysical Research: Oceans} \bold{99}, 10143--10162, 1994.}

\newcommand{\Evensen2009}{G. Evensen. \emph{Data assimilation: the ensemble Kalman filter}. Springer-Verlag, 2009.}

\newcommand{\he2010}{He, D., Ionides, E. L., and King, A. A. (2010). Plug-and-play inference for disease dynamics: measles in large and small populations as a case study. \emph{Journal of the Royal Society Interface}, \bold{7}(43), 271-283. \doi{10.1098/rsif.2009.0151}}

\newcommand{\ionides2006}{Ionides, E. L., Breto, C. and King, A. A. (2006) Inference for nonlinear dynamical systems. \emph{Proceedings of the National Academy of Sciences}, \bold{103(49)}, 18438--18443. \doi{10.1073/pnas.0603181103}}

\newcommand{\ionides2011}{Ionides, E. L., Bhadra, A., Atchade, Y. and King, A. A. (2011) Iterated filtering. \emph{Annals of Statists}, \bold{39, no. 3}, 1776--1802. \doi{10.1214/11-AOS886}}

\newcommand{\ionides2015}{Ionides, E. L., Nguyen, D., Atchade, Y., Stoev, S. and King, A. A. (2015) Inference via iterated, perturbed Bayes maps. \emph{Proceedings of the National Academy of Sciences}, \bold{112(3)}, 719--724. \doi{10.1073/pnas.1410597112}}

\newcommand{\ionides2021}{Ionides, E. L., Asfaw, K., Park, J., and King, A. A. (2021). Bagged filters for partially observed interacting systems. \emph{Journal of the American Statistical Association}, \doi{10.1080/01621459.2021.1974867}}

\newcommand{\ionides2022}{Ionides, E. L., Ning, N., and Wheeler, J. (2022). An iterated block particle filter for inference on coupled dynamic systems with shared and unit-specific parameters. \emph{Statistica Sinica}, to appear. \doi{10.48550/arXiv.2206.03837}}

\newcommand{\king2016}{King, A. A., Nguyen, D. and Ionides, E. L. (2016) Statistical Inference for Partially Observed Markov Processes via the R Package pomp. \emph{Journal of Statistical Software}, \bold{69(12)}, 1--43. \doi{10.18637/jss.v069.i12}}

\newcommand{\lorenz96}{Lorenz, E. N. (1996) Predictability: A problem partly solved. \emph{Proceedings of the seminar on predictability}}

\newcommand{\park2020}{Park, J. and Ionides, E. L. (2020) Inference on high-dimensional implicit dynamic models using a guided intermediate resampling filter. \emph{Statistics and Computing}, \doi{10.1007/s11222-020-09957-3}}

\newcommand{\rebeschini2015}{Rebeschini, P., & Van Handel, R. (2015). Can local particle filters beat the curse of dimensionality?. \emph{The Annals of Applied Probability}, \bold{25(5)}, 2809-2866.}

\newcommand{\sisson2007}{Sisson, S. A., Fan, Y. and Tanaka, M. M. (2007) Sequential Monte Carlo without likelihoods. \emph{Proceedings of the National Academy of Sciences}, \bold{104(6)}, 1760--1765. \doi{10.1073/pnas.0607208104}}

\newcommand{\sisson2009}{Sisson, S. A., Fan, Y. and Tanaka, M. M. (2009) Correction for Sisson et al., Sequential Monte Carlo without likelihoods. \emph{Proceedings of the National Academy of Sciences}, \bold{106(39)}, 16889. \doi{10.1073/pnas.0908847106}}

\newcommand{\tavare1997}{Tavare, S., Balding, D. J., Griffiths, R. C. and Donnelly, P. (1997) Inferring Coalescence Times from DNA Sequence Data. \emph{Genetics}, \bold{145(2)}, 505--518.}

==> spatPomp_0.31.0.0.tar.gz: spatPomp/man/macros/cite.Rd <==
% unlike in latex, new lines within \newcommand end the command (even using %)
\newcommand{\Anderson2001}{J.L. Anderson. An Ensemble Adjustment Kalman Filter for Data Assimilation. \emph{Monthly Weather Review} \bold{129}, 2884--2903, 2001.}

\newcommand{\arulampalam2002}{Arulampalam, M. S., Maskell, S., Gordon, N. and Clapp, T. (2002) A Tutorial on Particle Filters for Online Nonlinear/Non-Gaussian Bayesian Tracking. \emph{IEEE Trans. Sig. Proc.}, \bold{50(2)}, 174--188.}

\newcommand{\asfaw2020}{Asfaw, K., Park, J., Ho, A., King, A. A., and Ionides, E. L. (2020) Partially observed Markov processes with spatial structure via the R package spatPomp. \emph{ArXiv}: 2101.01157. \doi{10.48550/arXiv.2101.01157}}

\newcommand{\asfaw2021thesis}{Asfaw, K. T. (2021). Simulation-based Inference for Partially Observed Markov Process Models with Spatial Coupling. University of Michigan Doctoral dissertation. \doi{10.7302/2751}}

\newcommand{\breto2011}{Breto, C. and Ionides, E.L. (2011) Compound Markov counting processes and their applications to modeling infinitesimally over-dispersed systems. Stochastic Processes and their Applications \bold{121}, 2571-2591. \doi{10.1016/j.spa.2011.07.005}}

\newcommand{\breto2019}{Breto, C., Ionides, E. L. and King, A. A. (2019) Panel Data Analysis via Mechanistic Models. \emph{Journal of the American Statistical Association}. \doi{10.1080/01621459.2019.1604367}}

\newcommand{\dalziel2016}{Dalziel, Benjamin D. et al. (2016) Persistent chaos of measles epidemics in the prevaccination United States caused by a small change in seasonal transmission patterns. \emph{PLoS Computational Biology}, \bold{12(2)}, e1004655. \doi{10.5061/dryad.r4q34}}

\newcommand{\Evensen1994}{G. Evensen. Sequential data assimilation with a nonlinear quasi-geostrophic model using Monte Carlo methods to forecast error statistics. \emph{Journal of Geophysical Research: Oceans} \bold{99}, 10143--10162, 1994.}

\newcommand{\Evensen2009}{G. Evensen. \emph{Data assimilation: the ensemble Kalman filter}. Springer-Verlag, 2009.}

\newcommand{\he2010}{He, D., Ionides, E. L., and King, A. A. (2010). Plug-and-play inference for disease dynamics: measles in large and small populations as a case study. \emph{Journal of the Royal Society Interface}, \bold{7}(43), 271-283. \doi{10.1098/rsif.2009.0151}}

\newcommand{\ionides2006}{Ionides, E. L., Breto, C. and King, A. A. (2006) Inference for nonlinear dynamical systems. \emph{Proceedings of the National Academy of Sciences}, \bold{103(49)}, 18438--18443. \doi{10.1073/pnas.0603181103}}

\newcommand{\ionides2011}{Ionides, E. L., Bhadra, A., Atchade, Y. and King, A. A. (2011) Iterated filtering. \emph{Annals of Statists}, \bold{39, no. 3}, 1776--1802. \doi{10.1214/11-AOS886}}

\newcommand{\ionides2015}{Ionides, E. L., Nguyen, D., Atchade, Y., Stoev, S. and King, A. A. (2015) Inference via iterated, perturbed Bayes maps. \emph{Proceedings of the National Academy of Sciences}, \bold{112(3)}, 719--724. \doi{10.1073/pnas.1410597112}}

\newcommand{\ionides2021}{Ionides, E. L., Asfaw, K., Park, J., and King, A. A. (2021). Bagged filters for partially observed interacting systems. \emph{Journal of the American Statistical Association}, \doi{10.1080/01621459.2021.1974867}}

\newcommand{\ionides2022}{Ionides, E. L., Ning, N., and Wheeler, J. (2022). An iterated block particle filter for inference on coupled dynamic systems with shared and unit-specific parameters. \emph{Statistica Sinica}, to appear. \doi{10.48550/arXiv.2206.03837}}

\newcommand{\king2016}{King, A. A., Nguyen, D. and Ionides, E. L. (2016) Statistical Inference for Partially Observed Markov Processes via the R Package pomp. \emph{Journal of Statistical Software}, \bold{69(12)}, 1--43. \doi{10.18637/jss.v069.i12}}

\newcommand{\lorenz96}{Lorenz, E. N. (1996) Predictability: A problem partly solved. \emph{Proceedings of the seminar on predictability}}

\newcommand{\park2020}{Park, J. and Ionides, E. L. (2020) Inference on high-dimensional implicit dynamic models using a guided intermediate resampling filter. \emph{Statistics and Computing}, \doi{10.1007/s11222-020-09957-3}}

\newcommand{\rebeschini2015}{Rebeschini, P., & Van Handel, R. (2015). Can local particle filters beat the curse of dimensionality?. \emph{The Annals of Applied Probability}, \bold{25(5)}, 2809-2866.}

\newcommand{\sisson2007}{Sisson, S. A., Fan, Y. and Tanaka, M. M. (2007) Sequential Monte Carlo without likelihoods. \emph{Proceedings of the National Academy of Sciences}, \bold{104(6)}, 1760--1765. \doi{10.1073/pnas.0607208104}}

\newcommand{\sisson2009}{Sisson, S. A., Fan, Y. and Tanaka, M. M. (2009) Correction for Sisson et al., Sequential Monte Carlo without likelihoods. \emph{Proceedings of the National Academy of Sciences}, \bold{106(39)}, 16889. \doi{10.1073/pnas.0908847106}}

\newcommand{\tavare1997}{Tavare, S., Balding, D. J., Griffiths, R. C. and Donnelly, P. (1997) Inferring Coalescence Times from DNA Sequence Data. \emph{Genetics}, \bold{145(2)}, 505--518.}
